package com.ruoyi.ss.vipLevel.mapper;

import java.util.List;
import com.ruoyi.ss.vipLevel.domain.VipLevel;
import com.ruoyi.ss.vipLevel.domain.VipLevelVO;
import com.ruoyi.ss.vipLevel.domain.VipLevelQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 会员等级Mapper接口
 *
 * @author ruoyi
 * @date 2024-12-09
 */
public interface VipLevelMapper
{
    /**
     * 查询会员等级
     *
     * @param id 会员等级主键
     * @return 会员等级
     */
    public VipLevelVO selectVipLevelById(Long id);

    /**
     * 查询会员等级列表
     *
     * @param query 会员等级
     * @return 会员等级集合
     */
    public List<VipLevelVO> selectVipLevelList(@Param("query")VipLevelQuery query);

    /**
     * 新增会员等级
     *
     * @param vipLevel 会员等级
     * @return 结果
     */
    public int insertVipLevel(VipLevel vipLevel);

    /**
     * 修改会员等级
     *
     * @param vipLevel 会员等级
     * @return 结果
     */
    public int updateVipLevel(@Param("data") VipLevel vipLevel);

    /**
     * 删除会员等级
     *
     * @param id 会员等级主键
     * @return 结果
     */
    public int deleteVipLevelById(Long id);

    /**
     * 批量删除会员等级
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVipLevelByIds(@Param("ids") List<Long> ids);
}
